/*  GtkTransLabel v0.2 (gikocat project)
 *  Copyright (C) 1999, 2000
 *  gchar <gikokcat@gikocat.20m.com>
 *  for use in ǭץå as a Gnome Amusements Applet.
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "gtktranslabel.h"
#include <string.h>
#include <gdk/gdkx.h>
#include <gnome.h>
#include <X11/Xatom.h>

static void gtk_trans_label_class_init    (GtkTransLabelClass *klass);
static void gtk_trans_label_init          (GtkTransLabel      *trans_label);
static void gtk_trans_label_realize       (GtkWidget           *widget);
static void gtk_trans_label_size_request(GtkWidget *widget,
											GtkRequisition *requisition);
static void gtk_trans_label_size_allocate (GtkWidget           *widget,
                                            GtkAllocation       *allocation);
static void gtk_trans_label_send_configure (GtkTransLabel     *trans_label);
static gint gtk_trans_label_expose(GtkWidget *widget,
											GdkEventExpose  *event);
static gint gtk_trans_label_configure_event (GtkWidget *widget,
											GdkEventConfigure *event);
static void gtk_trans_label_destroy(GtkObject *object);

static GtkWidgetClass *parent_class = NULL;

GtkType
gtk_trans_label_get_type (void)
{
  static GtkType trans_label_type = 0;

  if (!trans_label_type)
    {
      static const GtkTypeInfo trans_label_info =
      {
        "GtkTransLabel",
        sizeof (GtkTransLabel),
        sizeof (GtkTransLabelClass),
        (GtkClassInitFunc) gtk_trans_label_class_init,
        (GtkObjectInitFunc) gtk_trans_label_init,
        /* reserved_1 */ NULL,
        /* reserved_2 */ NULL,
        (GtkClassInitFunc) NULL,
      };

      trans_label_type = gtk_type_unique (GTK_TYPE_WIDGET, &trans_label_info);    }

  return trans_label_type;
}


static void
gtk_trans_label_class_init (GtkTransLabelClass *class)
{
  GtkWidgetClass *widget_class;
  GtkObjectClass *object_class;
  
  parent_class = gtk_type_class (gtk_widget_get_type());
  
  widget_class = GTK_WIDGET_CLASS (class);
  object_class = (GtkObjectClass *) class;

  widget_class->realize = gtk_trans_label_realize;
  widget_class->size_allocate = gtk_trans_label_size_allocate;
  widget_class->expose_event = gtk_trans_label_expose;
  widget_class->size_request = gtk_trans_label_size_request;
  /*mwidget_class->configure_event = gtk_trans_label_configure_event;*/
  
  object_class->destroy = gtk_trans_label_destroy;
}


static void
gtk_trans_label_init (GtkTransLabel *trans_label)
{
  trans_label->draw_data = NULL;
  trans_label->label = NULL;
  trans_label->row = NULL;
  trans_label->transparent_value = 190;
  
}


GtkWidget*
gtk_trans_label_new (void)
{
	
	
  return GTK_WIDGET (gtk_type_new(gtk_trans_label_get_type()));
}


void
gtk_trans_label_size (GtkTransLabel *trans_label,
                       gint            width,
                       gint            height)
{
  g_return_if_fail (GTK_IS_TRANS_LABEL (trans_label));

  GTK_WIDGET (trans_label)->requisition.width = width;
  GTK_WIDGET (trans_label)->requisition.height = height;

  gtk_widget_queue_resize (GTK_WIDGET (trans_label));
}


static void
gtk_trans_label_realize (GtkWidget *widget)
{
  GtkTransLabel *trans_label;
  GdkWindowAttr attributes;
  gint attributes_mask;

  g_return_if_fail (widget != NULL);
  g_return_if_fail (GTK_IS_TRANS_LABEL (widget));

  trans_label = GTK_TRANS_LABEL (widget);
  GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);

  attributes.window_type = GDK_WINDOW_CHILD;
  attributes.x = widget->allocation.x;
  attributes.y = widget->allocation.y;
  attributes.width = widget->allocation.width;
  attributes.height = widget->allocation.height;
  attributes.wclass = GDK_INPUT_OUTPUT;
  attributes.visual = gtk_widget_get_visual (widget);
  attributes.colormap = gtk_widget_get_colormap (widget);
  attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;

  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;

  widget->window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
  gdk_window_set_user_data (widget->window, trans_label);

  widget->style = gtk_style_attach (widget->style, widget->window);
  gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);

  gtk_trans_label_send_configure (GTK_TRANS_LABEL (widget));
}

static void
gtk_trans_label_size_request(GtkWidget *widget, GtkRequisition *requisition)
{
	GtkTransLabel *trans_label;
	GList *row;
	gint width;
	
	g_return_if_fail(widget != NULL);
	g_return_if_fail(GTK_IS_TRANS_LABEL(widget));
	g_return_if_fail(requisition != NULL);
	
	/*g_print("size_request\n");*/
	
	trans_label = GTK_TRANS_LABEL(widget);
	
	row = trans_label->row;
	width = 0;
	
	while(row)
		{
		/*ʸʣԤξ*/
		if(row->next)
			width = MAX(width, gdk_text_width(GTK_WIDGET(trans_label)->style->font,
						row->data, (gchar *)row->next->data - (gchar *)row->data -1));
		
		/*ʸ1Ԥξ*/
		else
			width = MAX(width, gdk_string_width(GTK_WIDGET(trans_label)->style->font, row->data));
			
		row = row->next;
		
		requisition->width = width + 2;
		/*ǭѤ˺Ǹ + 2.0 Ĵ*/
		requisition->height = ((GTK_WIDGET(trans_label)->style->font->ascent +
										GTK_WIDGET(trans_label)->style->font->descent + 2) * 
										g_list_length(trans_label->row) + 2.0);
		}
		/*g_print("width = %d\n", width);*/
}


static void
gtk_trans_label_size_allocate (GtkWidget     *widget,
                                GtkAllocation *allocation)
{
  g_return_if_fail (widget != NULL);
  g_return_if_fail (GTK_IS_TRANS_LABEL (widget));
  g_return_if_fail (allocation != NULL);

  widget->allocation = *allocation;
  /* FIXME, TODO-1.3: back out the MAX() statements */
  widget->allocation.width = MAX (1, widget->allocation.width);
  widget->allocation.height = MAX (1, widget->allocation.height);

  if (GTK_WIDGET_REALIZED (widget))
    {
      gdk_window_move_resize (widget->window,
                              allocation->x, allocation->y,
                              allocation->width, allocation->height);

      gtk_trans_label_send_configure (GTK_TRANS_LABEL (widget));
    }
}


static void
gtk_trans_label_send_configure (GtkTransLabel *trans_label)
{
  GtkWidget *widget;
  GdkEventConfigure event;

  widget = GTK_WIDGET (trans_label);

  event.type = GDK_CONFIGURE;
  event.window = widget->window;
  event.send_event = TRUE;
  event.x = widget->allocation.x;
  event.y = widget->allocation.y;
  event.width = widget->allocation.width;
  event.height = widget->allocation.height;

  gtk_widget_event (widget, (GdkEvent*) &event);
}



static Window
get_desktop_window (Window the_window)
{
  Atom prop, type, prop2;
  int format;
  unsigned long length, after;
  unsigned char *data;
  unsigned int nchildren;
  Window w, root, *children, parent;
  
  prop = XInternAtom(GDK_DISPLAY(), "_XROOTPMAP_ID", True);
  prop2 = XInternAtom(GDK_DISPLAY(), "_XROOTCOLOR_PIXEL", True);
  
  if (prop == None && prop2 == None)
    return None;
  
#ifdef WATCH_DESKTOP_OPTION
  if (Options & Opt_watchDesktop)  {
    if (TermWin.wm_parent != None)
      XSelectInput(GDK_DISPLAY(), TermWin.wm_parent, None);
    
    if (TermWin.wm_grandparent != None)
      XSelectInput(GDK_DISPLAY(), TermWin.wm_grandparent, None);
  }
#endif
  
  for (w = the_window; w; w = parent) {
    if ((XQueryTree(GDK_DISPLAY(), w, &root, &parent, &children, &nchildren)) == False) 
      return None;
      
    if (nchildren) 
      XFree(children);

#ifdef WATCH_DESKTOP_OPTION
    if (Options & Opt_watchDesktop) {
      if (w == TermWin.parent) {
	TermWin.wm_parent = parent;
	XSelectInput(GDK_DISPLAY(), TermWin.wm_parent, StructureNotifyMask);
      } else if (w == TermWin.wm_parent) {
	TermWin.wm_grandparent = parent;
	XSelectInput(GDK_DISPLAY(), TermWin.wm_grandparent, StructureNotifyMask);
      }
    }
#endif
    
    if (prop != None) {
      XGetWindowProperty(GDK_DISPLAY(), w, prop, 0L, 1L, False, AnyPropertyType,
			 &type, &format, &length, &after, &data);
    } else if (prop2 != None) {
      XGetWindowProperty(GDK_DISPLAY(), w, prop2, 0L, 1L, False, AnyPropertyType,
			 &type, &format, &length, &after, &data);
    } else  {
      continue;
    }
    
    if (type != None) {
      return w;
    }
  }
  
  return None;
}


static Pixmap
get_pixmap_prop (Window the_window, char *prop_id)
{
  Atom prop, type;
  int format;
  unsigned long length, after;
  unsigned char *data;
  Window desktop_window;

  /*this should be changed when desktop changes I guess*/
  /*if(desktop_window == None)*/
  desktop_window = get_desktop_window(the_window);
  if(desktop_window == None)
    desktop_window = GDK_ROOT_WINDOW();
  
  prop = XInternAtom(GDK_DISPLAY(), prop_id, True);
  
  if (prop == None)
    return None;
  
  XGetWindowProperty(GDK_DISPLAY(), desktop_window, prop, 0L, 1L, False,
		     AnyPropertyType, &type, &format, &length, &after,
		     &data);
	
  if (type == XA_PIXMAP)
    return *((Pixmap *)data);
	
  return None;
}


static GdkPixmap *
create_normal_pixmap (Pixmap p, int x, int y, int w, int h, int transparent_value)
{
  GdkPixmap *pix,*pp,*tmp;
  GdkImlibColorModifier mod;
  GdkImlibImage *iim;
  GdkGC *tgc;
  int width,height,depth;
  
  if (p == None)
    return NULL;

  pp = gdk_pixmap_foreign_new(p);
  gdk_window_get_geometry(pp,NULL,NULL,&width,&height,&depth);

  if (width<x+w || height<y+h || x<0 || y<0) {
    tgc = gdk_gc_new(pp);
    tmp = gdk_pixmap_new(pp,w,h,depth);
    
    gdk_gc_set_tile (tgc, pp);
    gdk_gc_set_fill (tgc, GDK_TILED);
    gdk_gc_set_ts_origin(tgc, -x, -y);
    gdk_draw_rectangle (tmp, tgc, TRUE, 0, 0, w, h);
    gdk_gc_destroy(tgc);
    
    iim = gdk_imlib_create_image_from_drawable(tmp,
					       NULL, 0, 0, w, h);
    gdk_pixmap_unref(tmp);
  } else {
    iim = gdk_imlib_create_image_from_drawable(pp,
					       NULL, x, y, w, h);
  }
  gdk_xid_table_remove (GDK_WINDOW_XWINDOW(pp));
  g_dataset_destroy (pp);
  g_free (pp);

  if(!iim)
    return NULL;

  mod.contrast = 256;
  mod.brightness = transparent_value;
  mod.gamma = 256;
  gdk_imlib_set_image_modifier (iim, &mod);
  gdk_imlib_render (iim, iim->rgb_width, iim->rgb_height);
  pix = gdk_imlib_move_image (iim);
  gdk_imlib_destroy_image (iim);
  
  return pix;
}

void
load_background(GtkWidget *widget)
{
	Window childret;
	Pixmap p;
	gint px, py, pwidth, pheight;
	gint transparent_value = 190;
	
	 p = get_pixmap_prop (GDK_WINDOW_XWINDOW(GTK_WIDGET(widget)->window), "_XROOTPMAP_ID");
 	 if (p == None) {
   		
    	return;
     }
     
     /*кɸ*/
     /*gdk_window_get_positionǤ褤*/
     XTranslateCoordinates(GDK_WINDOW_XDISPLAY(GTK_WIDGET(widget)->window),
     								GDK_WINDOW_XWINDOW(GTK_WIDGET(widget)->window),
     								GDK_ROOT_WINDOW(),
     								0, 0,
     								&px, &py,
     								&childret);
     /*g_print("px = %d py = %d\n", px, py);*/
     
     gdk_window_get_size(GTK_WIDGET(widget)->window, &pwidth, &pheight);
     
     /*pixmap = gdk_pixmap_foreign_new(p);*/
     
     /*pixmap = create_shaded_pixmap(p, px, py, width, pheight);*/
     
     transparent_value = GTK_TRANS_LABEL(widget)->transparent_value;
     GTK_TRANS_LABEL(widget)->pixmap = create_normal_pixmap(p, px, py, pwidth, pheight, transparent_value);
     
    
}

static gint
gtk_trans_label_expose (GtkWidget      *widget, GdkEventExpose *event)
{
	GtkTransLabel *trans_label;
	GList *row;
	gint state;
	gint offset = 0;
	gint len;
	gint maxl;
	gint x, y;
	GdkFont *font;
	
	g_return_val_if_fail(widget != NULL, FALSE);
	g_return_val_if_fail(GTK_TRANS_LABEL(widget), FALSE);
	g_return_val_if_fail(event != NULL, FALSE);
	
	
	/*g_print("expose\n");*/
	
	trans_label = GTK_TRANS_LABEL(widget);

	if(GTK_WIDGET_DRAWABLE(widget))
		{
		/*ȾƩ*/
		load_background(widget);
	
		gdk_draw_pixmap(widget->window, GTK_WIDGET(trans_label)->style->fg_gc[0], GTK_TRANS_LABEL(widget)->pixmap, 0,0,
													event->area.x, event->area.y,  event->area.width, event->area.height);
		}
	
	if(trans_label->label)
	{
		
		state = widget->state;
		maxl = widget->requisition.width;
		
		x = widget->allocation.x + (widget->allocation.width / 2) + 0.5;
		
		/*ǭѤĴ*/
		/*y = widget->allocation.y + (widget->allocation.height / 2) + 0.5;*/
		y = (widget->allocation.height / 2) + 5.0;

		row = trans_label->row;
		/*g_print("rows = %d\n", g_list_length(row));*/
		if(g_list_length(row) != 1)
			/*y -= ((widget->style->font->ascent + widget->style->font->descent + 2) * (g_list_length(row))) / 2;*/
			y -= (((widget->style->font->ascent ) * (g_list_length(row))) + widget->style->font->descent) / 2;
		
		while(row && row->next)
			{
				/*g_print("data = %s\n", row->data);*/
				
				len = (gchar*) row->next->data - (gchar*) row->data - 1;
				offset = gdk_text_width(widget->style->font, row->data, len) / 2;
				
				/*g_print("x = %d y = %d\n", x, y);*/
				gdk_draw_text (widget->window, widget->style->font,
                         widget->style->fg_gc[state],
                         -offset + x, y, row->data, len);
				
				row = row->next;
         		 y += widget->style->font->ascent + widget->style->font->descent + 2;
      	    		}
      	    
      	    offset = 0;
      	    offset = gdk_string_width (widget->style->font, row->data) / 2;
      	    
      	    g_print("y = %d\n", y);
      	    gdk_draw_string (widget->window, widget->style->font,
                       widget->style->fg_gc[state],
                       -offset + x, y, row->data);
	}
		
	return TRUE;
}


static gint
gtk_trans_label_configure_event (GtkWidget         *widget,
                            GdkEventConfigure *event)
{
	GdkEventExpose expose_event;
	GdkRectangle update_rect;
	gint window_width;
	gint window_height;
	
	g_return_val_if_fail (widget != NULL, FALSE);
    g_return_val_if_fail (GTK_IS_TRANS_LABEL (widget), FALSE);
    g_return_val_if_fail (event != NULL, FALSE);
	/*g_print("configure_event\n");*/
	
	gdk_window_get_size(widget->window, &window_width, &window_height);
	
	update_rect.x = 0;
	update_rect.y = 0;
	update_rect.width = window_width;
	update_rect.height = window_height;
	gtk_widget_draw(widget, &update_rect);
	
	expose_event.type = GDK_EXPOSE;
	expose_event.send_event = TRUE;
	expose_event.window = widget->window;
	expose_event.area = update_rect;
	expose_event.count = 0;
	
	/*gtk_trans_label_expose(widget, (GdkEventExpose *)&expose_event);*/
	
	return TRUE;
}


void
show_data(gpointer data ,gpointer user_data)
{
 gchar *message;

 message = (gchar *)data;
 g_print("%s ",message);
}


void
gtk_trans_label_set(GtkTransLabel *trans_label,	const gchar *str)
{
	GdkFont *font;
	GdkColor white;
	gchar *p;
	
	g_return_if_fail(trans_label != NULL);
	g_return_if_fail(GTK_IS_TRANS_LABEL(trans_label));
	g_return_if_fail(str != NULL);
	
	if(trans_label->label)
		g_free(trans_label->label);
	trans_label->label = g_strdup(str);
	
	if(trans_label->row)
		g_list_free(trans_label->row);
	trans_label->row = NULL;
	trans_label->row = g_list_append(trans_label->row, trans_label->label);
	
	p = trans_label->label;
	while((p = strchr(p, '\n')))
		trans_label->row = g_list_append(trans_label->row, ++p);
	
	/*g_list_foreach(trans_label->row ,(GFunc)show_data ,NULL);*/
	
	/*gdk_window_clear򤹤ȸƤФ٤˸롣ǤƤФʤ*/
	if(GTK_WIDGET_DRAWABLE(GTK_WIDGET(trans_label)))
		/*gdk_window_clear(GTK_WIDGET(trans_label)->window);*/
		
	font = gdk_fontset_load("-*-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*,
									-*-fixed-medium-r-*-*-12-*-*-*-*-*-jisx0208.1983-*");
	
/*	gdk_draw_string(GTK_WIDGET(trans_label)->window, font, GTK_WIDGET(trans_label)->style->fg_gc[0],
								 50, 50, trans_label->label);*/
								 
	gtk_trans_label_send_configure (GTK_TRANS_LABEL (trans_label));
	
	/*ɬɬ*/
	gtk_widget_queue_resize(GTK_WIDGET(trans_label));
}

void
gtk_trans_label_set_trans(GtkTransLabel *trans_label, gint percent)
{
	g_return_if_fail(trans_label != NULL);
	g_return_if_fail(GTK_IS_TRANS_LABEL(trans_label));
	
	trans_label->transparent_value = percent * 2.56;
	/*g_print("value = %d\n", trans_label->transparent_value);*/
	
	gtk_widget_queue_resize(GTK_WIDGET(trans_label));
}


void
gtk_trans_label_set_color(GtkTransLabel *trans_label, GtkTransLabelColor color_type)
{
	GdkColor color;
	GtkStyle *style;
	
	g_return_if_fail(trans_label != NULL);
	g_return_if_fail(GTK_IS_TRANS_LABEL(trans_label));
	g_return_if_fail(0 <= color_type || color_type <= 10);
	
	
	switch(color_type)
		{
		case GTK_TRANS_LABEL_BLACK:
			color.red = 0;
			color.green = 0;
			color.blue = 0;
			break;
		
		case GTK_TRANS_LABEL_WHITE:
			color.red = 65535;
			color.green = 65535;
			color.blue = 65535;
			break;
			
		case GTK_TRANS_LABEL_RED:
			color.red = 64224;
			color.green = 9175;
			color.blue = 16384;
			break;
		
		case GTK_TRANS_LABEL_GREEN:
			color.red = 13107;
			color.green = 47840;
			color.blue = 0;
			break;
			
		case GTK_TRANS_LABEL_BLUE:
			color.red = 32112;
			color.green = 29490;
			color.blue = 64224;
			break;
			
		case GTK_TRANS_LABEL_YELLOW:
			color.red = 62913;
			color.green = 52428;
			color.blue = 10485;
			break;
			
		case GTK_TRANS_LABEL_PERPLE:
			color.red = 50461;
			color.green = 16383;
			color.blue = 58326;
			break;
		
		case GTK_TRANS_LABEL_PINK:
			color.red = 64224;
			color.green = 52428;
			color.blue = 61602;
			break;
			
		case GTK_TRANS_LABEL_ORANGE:
			color.red = 65535;
			color.green = 36044;
			color.blue = 17039;
			break;
	
	  case GTK_TRANS_LABEL_MAZENDA:
	  		color.red = 00000;
			color.green = 50000;
			color.blue = 65535;
			break;
		
	  case GTK_TRANS_LABEL_GLAY:
	  		color.red = 32896;
			color.green = 32896;
			color.blue = 32896;
			break;
	
	  case GTK_TRANS_LABEL_SILVER:
	  		color.red = 49344;
			color.green = 49344;
			color.blue = 49344;
			break;
	  
	  case GTK_TRANS_LABEL_OLIVE:
	  		color.red = 32896;
			color.green = 32896;
			color.blue = 0;
			break;
			
	  case GTK_TRANS_LABEL_GOLDENROD:
	  		color.red = 56026;
			color.green = 42405;
			color.blue = 8224;
			break;
			
	  case GTK_TRANS_LABEL_NAVY:
	  		color.red = 0;
			color.green = 0;
			color.blue = 32896;
			break;
		}
		
		gdk_color_alloc(gdk_colormap_get_system(), &color);
		/*gdk_gc_set_foreground(GTK_WIDGET(trans_label)->style->fg_gc[0], &color);*/
		style = gtk_style_copy(GTK_WIDGET(trans_label)->style);
		style->fg[0] = color;
		gtk_widget_set_style(GTK_WIDGET(trans_label), style);
		
		/*ǥɥ򥯥ꥢ ɬ*/
		/*ޤǤΥǥեȤιĤäƤ뤫顣ꥢ
		gdk_window_clearϤǤƤӤʤ*/
		/*if(GTK_WIDGET_DRAWABLE(GTK_WIDGET(trans_label)))
			gdk_window_clear(GTK_WIDGET(trans_label)->window);*/
		gtk_widget_queue_resize(GTK_WIDGET(trans_label));
}


void
gtk_trans_label_set_font(GtkTransLabel *trans_label, GtkTransLabelFont font_type)
{
	GtkStyle *style;
	GdkFont	*font;
	
	g_return_if_fail(trans_label != NULL);
	g_return_if_fail(GTK_IS_TRANS_LABEL(trans_label));
	g_return_if_fail(0 <= font_type || font_type <= 5);
	
	style = gtk_style_copy(GTK_WIDGET(trans_label)->style);
	
	switch(font_type)
	  {
		case 0:/*ɸ*/
			
			font = gdk_fontset_load("-*-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*,
									-*-fixed-medium-r-*-*-12-*-*-*-*-*-jisx0208.1983-*");
			break;
			
		case 1:/*(kappa)*/
			font = gdk_fontset_load("-*-helvetica-medium-r-*-*-8-*-*-*-*-*-*-*,
									-kappa-*-medium-r-normal-*-8-*-*-*-*-*-jisx0208.1983-*");
			break;
			
		case 2:/*(misc)*/
			font = gdk_fontset_load("-*-helvetica-medium-r-*-*-8-*-*-*-*-*-*-*,
									-misc-fixed-medium-r-normal-*-8-*-*-*-*-*-jisx0208.1983-*");
			break;
			
		case 3:/*(alias)*/
			font = gdk_fontset_load("-*-helvetica-medium-r-*-*-8-*-*-*-*-*-*-*,
									-alias-*-medium-r-normal-*-8-*-*-*-*-*-jisx0208.1983-*");
			break;
	
		case 4:/*(mnkana)*/
			font = gdk_fontset_load("-*-helvetica-medium-r-*-*-8-*-*-*-*-*-*-*,
									-mnkaname-*-medium-r-normal-*-8-*-*-*-*-*-jisx0208.1983-*");
			break;
			
		case 5:
			font = gdk_fontset_load("-*-helvetica-medium-r-*-*-16-*-*-*-*-*-*-*,
									-*-fixed-medium-r-*-*-16-*-*-*-*-*-jisx0208.1983-*");
			break;
	  }
	  
	  style->font = font;
	  gtk_widget_set_style(GTK_WIDGET(trans_label),style);
	  
	  gtk_widget_queue_resize(GTK_WIDGET(trans_label));

}


void
gtk_trans_label_get(GtkTransLabel *trans_label,	gchar **str)
{
	g_return_if_fail(trans_label != NULL);
	g_return_if_fail(GTK_IS_TRANS_LABEL(trans_label));
	g_return_if_fail(str != NULL);
	
	*str = trans_label->label;
}


static void
gtk_trans_label_destroy (GtkObject *object)
{
  GtkTransLabel *trans_label;
  GtkTransLabelClass *class;
  GSList *list;

  g_return_if_fail (object != NULL);
  g_return_if_fail (GTK_IS_TRANS_LABEL (object));

	trans_label = GTK_TRANS_LABEL(object);

	if(trans_label->label)
		g_free(trans_label->label);
		
	trans_label->label = NULL;
	
	if(trans_label->draw_data)
		g_free(trans_label->draw_data);
	
	g_list_free(trans_label->row);
	trans_label->draw_data;
	
	GTK_OBJECT_CLASS (parent_class)->destroy (object);
}  
